#line 1 "pkl-lex.c"
   /* This code goes at the "top" of the generated file.  */
   #include <config.h>

#line 5 "pkl-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define pkl_tab__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer pkl_tab__create_buffer
#endif

#ifdef yy_delete_buffer
#define pkl_tab__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer pkl_tab__delete_buffer
#endif

#ifdef yy_scan_buffer
#define pkl_tab__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer pkl_tab__scan_buffer
#endif

#ifdef yy_scan_string
#define pkl_tab__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string pkl_tab__scan_string
#endif

#ifdef yy_scan_bytes
#define pkl_tab__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes pkl_tab__scan_bytes
#endif

#ifdef yy_init_buffer
#define pkl_tab__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer pkl_tab__init_buffer
#endif

#ifdef yy_flush_buffer
#define pkl_tab__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer pkl_tab__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define pkl_tab__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state pkl_tab__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define pkl_tab__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer pkl_tab__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define pkl_tab_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state pkl_tab_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define pkl_tab_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state pkl_tab_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define pkl_tab_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack pkl_tab_ensure_buffer_stack
#endif

#ifdef yylex
#define pkl_tab_lex_ALREADY_DEFINED
#else
#define yylex pkl_tab_lex
#endif

#ifdef yyrestart
#define pkl_tab_restart_ALREADY_DEFINED
#else
#define yyrestart pkl_tab_restart
#endif

#ifdef yylex_init
#define pkl_tab_lex_init_ALREADY_DEFINED
#else
#define yylex_init pkl_tab_lex_init
#endif

#ifdef yylex_init_extra
#define pkl_tab_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra pkl_tab_lex_init_extra
#endif

#ifdef yylex_destroy
#define pkl_tab_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy pkl_tab_lex_destroy
#endif

#ifdef yyget_debug
#define pkl_tab_get_debug_ALREADY_DEFINED
#else
#define yyget_debug pkl_tab_get_debug
#endif

#ifdef yyset_debug
#define pkl_tab_set_debug_ALREADY_DEFINED
#else
#define yyset_debug pkl_tab_set_debug
#endif

#ifdef yyget_extra
#define pkl_tab_get_extra_ALREADY_DEFINED
#else
#define yyget_extra pkl_tab_get_extra
#endif

#ifdef yyset_extra
#define pkl_tab_set_extra_ALREADY_DEFINED
#else
#define yyset_extra pkl_tab_set_extra
#endif

#ifdef yyget_in
#define pkl_tab_get_in_ALREADY_DEFINED
#else
#define yyget_in pkl_tab_get_in
#endif

#ifdef yyset_in
#define pkl_tab_set_in_ALREADY_DEFINED
#else
#define yyset_in pkl_tab_set_in
#endif

#ifdef yyget_out
#define pkl_tab_get_out_ALREADY_DEFINED
#else
#define yyget_out pkl_tab_get_out
#endif

#ifdef yyset_out
#define pkl_tab_set_out_ALREADY_DEFINED
#else
#define yyset_out pkl_tab_set_out
#endif

#ifdef yyget_leng
#define pkl_tab_get_leng_ALREADY_DEFINED
#else
#define yyget_leng pkl_tab_get_leng
#endif

#ifdef yyget_text
#define pkl_tab_get_text_ALREADY_DEFINED
#else
#define yyget_text pkl_tab_get_text
#endif

#ifdef yyget_lineno
#define pkl_tab_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno pkl_tab_get_lineno
#endif

#ifdef yyset_lineno
#define pkl_tab_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno pkl_tab_set_lineno
#endif

#ifdef yyget_column
#define pkl_tab_get_column_ALREADY_DEFINED
#else
#define yyget_column pkl_tab_get_column
#endif

#ifdef yyset_column
#define pkl_tab_set_column_ALREADY_DEFINED
#else
#define yyset_column pkl_tab_set_column
#endif

#ifdef yywrap
#define pkl_tab_wrap_ALREADY_DEFINED
#else
#define yywrap pkl_tab_wrap
#endif

/* %endif */

#ifdef yyget_lval
#define pkl_tab_get_lval_ALREADY_DEFINED
#else
#define yyget_lval pkl_tab_get_lval
#endif

#ifdef yyset_lval
#define pkl_tab_set_lval_ALREADY_DEFINED
#else
#define yyset_lval pkl_tab_set_lval
#endif

#ifdef yyget_lloc
#define pkl_tab_get_lloc_ALREADY_DEFINED
#else
#define yyget_lloc pkl_tab_get_lloc
#endif

#ifdef yyset_lloc
#define pkl_tab_set_lloc_ALREADY_DEFINED
#else
#define yyset_lloc pkl_tab_set_lloc
#endif

#ifdef yyalloc
#define pkl_tab_alloc_ALREADY_DEFINED
#else
#define yyalloc pkl_tab_alloc
#endif

#ifdef yyrealloc
#define pkl_tab_realloc_ALREADY_DEFINED
#else
#define yyrealloc pkl_tab_realloc
#endif

#ifdef yyfree
#define pkl_tab_free_ALREADY_DEFINED
#else
#define yyfree pkl_tab_free
#endif

/* %if-c-only */

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* %endif */

/* %if-not-reentrant */
/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

/* %endif */

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define pkl_tab_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	yyg->yy_c_buf_p = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 142
#define YY_END_OF_BUFFER 143
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[477] =
    {   0,
      143,  141,  142,    2,  141,  142,    1,  142,    3,  141,
      142,  141,  142,  113,  141,  142,  141,  142,  141,  142,
      141,  142,  112,  141,  142,  103,  141,  142,  141,  142,
       92,  141,  142,   93,  141,  142,  109,  141,  142,  106,
      141,  142,   96,  141,  142,  107,  141,  142,  115,  141,
      142,  111,  141,  142,  138,  141,  142,  138,  141,  142,
      100,  141,  142,   99,  141,  142,  104,  141,  142,   97,
      141,  142,  105,  141,  142,   98,  141,  142,  117,  141,
      142,  137,  141,  142,   90,  141,  142,   91,  141,  142,
      102,  141,  142,  137,  141,  142,  137,  141,  142,  137,

      141,  142,  137,  141,  142,  137,  141,  142,  137,  141,
      142,  137,  141,  142,  137,  141,  142,  137,  141,  142,
      137,  141,  142,  137,  141,  142,  137,  141,  142,  137,
      141,  142,  137,  141,  142,  137,  141,  142,  137,  141,
      142,  137,  141,  142,   94,  141,  142,  101,  141,  142,
       95,  141,  142,  114,  141,  142,    6,  142,    7,  142,
        6,  142,   10,  142,   11,  142,   10,  142,    1,   81,
      140,    8,  135,  135,  136,  133,   67,   78,   72,  134,
      108,   65,   86,   63,   68,   87,   69,   88,  130,  127,
      124,  125,  129,  120,  121,    4,   12,   66,  110,  138,

      138,  138,  138,  138,   82,   80,   79,   83,   76,  116,
      137,   89,   89,   89,   74,  137,  137,  137,   39,  137,
      137,  137,  137,  137,  137,  137,  137,  137,   25,  137,
      137,   23,  137,  137,  137,  137,  137,  137,  137,  137,
      137,  137,  137,  137,  137,  137,  137,  137,  137,  137,
      137,  137,   73,   77,    5,    9,  135,  136,  133,  133,
      139,  134,   64,  119,  126,  131,  132,   62,  128,  122,
      118,  123,   85,   12,  138,  138,  138,  138,  138,   75,
       84,   89,   89,  137,  137,   44,  137,  137,  137,   15,
      137,  137,   50,  137,  137,  137,  137,  137,  137,  137,

       22,  137,   30,  137,  137,  137,   47,  137,  137,  137,
      137,  137,  137,  137,  137,  137,  137,  137,  137,  137,
       40,  137,  137,  137,  137,  137,  137,   33,  137,  137,
      137,  137,  135,  135,  135,   71,  138,  138,  138,  138,
       70,  137,  137,   29,  137,  137,  137,  137,  137,  137,
      137,   19,  137,   56,  137,  137,  137,   60,  137,  137,
       52,  137,  137,  137,  137,  137,  137,  137,  137,  137,
      137,  137,   32,  137,  137,  137,   34,  137,  137,  137,
       43,  137,  137,  137,  135,  135,  135,  133,  138,  137,
      137,   28,  137,  137,   35,  137,   41,  137,  137,  137,

      137,  137,  137,  137,  137,  137,  137,   45,  137,   42,
      137,   49,  137,  137,  137,  137,  137,  137,   59,   18,
      137,   48,  137,   21,  137,   24,  137,   20,  137,  137,
      137,   54,  137,  137,  137,   55,  137,  137,   53,  137,
       51,  137,   31,  137,  137,   16,  137,   46,  137,   37,
      137,   26,  137,   38,  137,   17,  137,   27,  137,  137,
      137,  137,  137,  137,   61,   14,  137,   13,  137,   57,
      137,   36,  137,  137,   58,  137
    } ;

static const flex_int16_t yy_accept[352] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    2,    4,    7,
        9,   12,   14,   17,   19,   21,   23,   26,   29,   31,
       34,   37,   40,   43,   46,   49,   52,   55,   58,   61,
       64,   67,   70,   73,   76,   79,   82,   85,   88,   91,
       94,   97,  100,  103,  106,  109,  112,  115,  118,  121,
      124,  127,  130,  133,  136,  139,  142,  145,  148,  151,
      154,  157,  159,  161,  163,  165,  167,  169,  170,  171,
      171,  172,  172,  173,  174,  175,  176,  177,  177,  178,
      179,  180,  180,  181,  181,  182,  183,  184,  185,  186,
      187,  188,  189,  189,  190,  191,  192,  193,  193,  194,

      195,  195,  196,  197,  198,  199,  200,  201,  202,  203,
      203,  204,  205,  205,  205,  205,  206,  207,  208,  209,
      210,  211,  212,  213,  214,  215,  216,  217,  218,  219,
      221,  222,  223,  224,  225,  226,  227,  228,  229,  231,
      232,  234,  235,  236,  237,  238,  239,  240,  241,  242,
      243,  244,  245,  246,  247,  248,  249,  250,  251,  252,
      253,  254,  255,  256,  257,  258,  258,  258,  258,  259,
      260,  260,  260,  261,  262,  263,  263,  264,  265,  266,
      267,  268,  269,  270,  271,  272,  273,  274,  275,  276,
      277,  278,  279,  280,  281,  282,  283,  284,  285,  286,

      288,  289,  290,  292,  293,  295,  296,  297,  298,  299,
      300,  301,  303,  305,  306,  307,  309,  310,  311,  312,
      313,  314,  315,  316,  317,  318,  319,  320,  321,  323,
      324,  325,  326,  327,  328,  330,  331,  332,  333,  334,
      335,  336,  336,  336,  337,  338,  339,  340,  341,  342,
      343,  344,  346,  347,  348,  349,  350,  351,  352,  354,
      356,  357,  358,  359,  360,  361,  363,  364,  365,  366,
      367,  368,  369,  370,  371,  372,  373,  375,  376,  377,
      379,  380,  381,  383,  384,  385,  386,  387,  388,  389,
      390,  391,  392,  394,  395,  397,  399,  400,  401,  402,

      403,  404,  405,  406,  407,  408,  410,  412,  414,  415,
      416,  417,  418,  419,  420,  422,  424,  426,  428,  430,
      431,  432,  434,  435,  436,  438,  439,  441,  443,  445,
      446,  448,  450,  452,  454,  456,  458,  460,  461,  462,
      463,  464,  465,  466,  468,  470,  472,  474,  475,  477,
      477
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       23,   23,   23,   23,   23,   24,   24,   25,   26,   27,
       28,   29,   30,   31,   32,   33,   32,   32,   34,   35,
       36,   37,   38,   36,   36,   39,   36,   40,   41,   36,
       36,   36,   36,   42,   43,   36,   36,   44,   36,   36,
       45,   46,   47,   48,   49,    1,   50,   51,   52,   53,

       54,   55,   56,   57,   58,   36,   59,   60,   61,   62,
       63,   64,   36,   65,   66,   67,   68,   69,   70,   44,
       71,   72,   73,   74,   75,   76,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[77] =
    {   0,
        1,    1,    2,    1,    1,    3,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        5,    5,    5,    5,    6,    1,    7,    1,    1,    1,
        1,    5,    5,    5,    5,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    1,    1,    1,    1,    9,    5,
        5,    5,    5,    5,    5,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[366] =
    {   0,
        0,    0,   74,   75,   76,   77,  640,  641,  641,  641,
      641,  636,  610,   74,   78,  610,  608,   75,  120,  641,
      641,   70,   79,  641,   87,  191,  184,  212,  180,  610,
      641,   60,   63,  606,  627,  626,    0,  641,  248,  603,
      581,   44,   53,   46,   52,  135,  161,  167,  575,  573,
      150,   43,  147,   48,  179,  176,  570,  641,  172,  641,
      641,  641,  641,  606,  641,  641,  617,  641,  641,  221,
      641,    0,  641,  273,  279,    0,  599,  594,  641,  641,
      641,  610,  609,  297,  592,  641,  641,  641,  641,  641,
      641,  641,  591,  641,  603,  601,  598,  596,  566,  585,

      584,  219,  641,    0,  641,  641,    0,  243,  214,  237,
      641,  290,    0,  586,  591,  641,  641,  641,  641,  641,
      641,    0,  225,  641,  298,  641,  203,  538,  203,  212,
      552,  553,  539,  215,  539,  536,  538,  540,    0,  540,
      533,  549,  537,  530,  546,  528,  539,  531,  534,  533,
       56,  518,  524,  517,  523,  524,  231,  520,  526,  186,
      641,  641,  641,  641,  344,  262,  311,    0,    0,  558,
      557,  552,  641,  641,  568,  349,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  551,    0,  352,  641,
      356,  641,  385,  641,  550,  641,  641,  539,  538,    0,

      511,  508,    0,  519,    0,  522,  519,  506,  502,  514,
      506,  505,    0,  497,  537,    0,  512,  495,  506,  501,
      489,  492,  491,  478,  490,  471,  471,  286,    0,  466,
      452,  258,  465,  456,    0,  456,  440,  444,  291,  361,
        0,    0,  368,  641,    0,    0,    0,  283,  641,  463,
      432,    0,  413,  404,  408,  409,  397,  406,    0,    0,
      413,  394,  641,  407,  399,    0,  395,  403,  402,  388,
      400,  385,  381,  380,  379,  381,  369,  404,  368,    0,
      365,  366,    0,  367,  362,  364,  374,    0,  390,  411,
      380,  378,    0,  344,    0,    0,  337,  341,  335,  350,

      349,  344,  341,  325,  335,  332,    0,    0,  319,  314,
      307,  290,  301,  641,    0,    0,    0,    0,    0,  304,
      299,    0,  292,  277,    0,  291,    0,    0,    0,  312,
        0,    0,    0,    0,    0,    0,    0,  258,  255,  217,
      208,  190,  641,    0,    0,    0,    0,  175,    0,  641,
      473,  482,  491,  498,  503,  508,  513,  518,  527,  533,
      542,  197,   89,  547,  552
    } ;

static const flex_int16_t yy_def[366] =
    {   0,
      350,    1,  351,  351,  352,  352,  350,  350,  350,  350,
      350,  350,  350,  353,  354,  355,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,   28,  350,
      350,  350,  350,  350,  350,  350,  356,  350,  350,  350,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  353,
      350,  353,  350,  350,  350,  357,  358,  359,  350,  350,
      350,  350,  360,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,

      350,  350,  350,  361,  350,  350,   29,  350,  350,  350,
      350,  350,  362,  350,  350,  350,  350,  350,  350,  350,
      350,  356,  350,  350,  350,  350,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      350,  350,  350,  350,  350,  350,  350,  363,  357,  358,
      350,  359,  350,  350,  360,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  361,   29,  350,
      189,  350,  350,  350,  350,  350,  350,  356,  356,  356,

      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  350,  350,
      364,  365,  350,  350,  189,  191,  193,  193,  350,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  350,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  350,  350,  364,  358,  350,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,

      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  350,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  356,  356,  356,  356,  356,  356,  356,  356,
      356,  356,  350,  356,  356,  356,  356,  356,  356,    0,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350
    } ;

static const flex_int16_t yy_nxt[718] =
    {   0,
        8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
       18,   19,   20,   21,   22,   23,   24,   25,   26,   27,
       28,   29,   29,   29,   30,   31,   32,   33,   34,   35,
       36,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   38,    8,   39,   40,   41,   42,
       43,   44,   37,   45,   46,   37,   37,   47,   37,   48,
       49,   37,   50,   51,   52,   53,   54,   55,   56,   57,
       37,   37,   58,   59,   60,   61,   63,   63,   66,   66,
       71,   67,   67,   73,   85,   80,  115,  116,   64,   64,
      117,  118,  150,  241,   87,  133,  151,   86,   74,   75,

       75,   75,   81,   88,   90,  128,   89,  129,  134,  130,
      131,  135,  154,  136,   91,   92,  225,  132,  155,   72,
       82,   82,  226,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   82,   82,   82,   82,   82,   82,
       82,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   82,   84,   82,   82,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   82,   82,   82,   82,   93,  137,  103,  161,

       94,  193,  138,  104,  152,   95,   96,  148,   97,   98,
       99,  105,  109,  153,  149,  139,  143,  100,  101,  102,
      350,  140,  141,  350,  144,  158,  142,   71,  349,  145,
      109,  106,  107,  107,  107,  107,  156,  198,  159,  237,
      157,  199,  350,  238,  108,  162,  186,  187,  109,  348,
      109,  109,  110,  111,  112,  113,  190,  191,  191,  191,
      107,  347,  108,  189,  189,  201,   72,  196,  109,  346,
      202,  109,  203,  109,  110,  208,  209,  204,  111,  112,
      123,  190,  239,  239,  123,  190,  123,  123,  232,  124,
      125,  233,  196,  165,  165,  165,  165,  234,  123,  165,

      165,  165,  165,  345,  123,  166,  344,  123,  174,  123,
      190,  286,  286,  167,  124,  125,  168,  176,  176,  176,
      279,  165,  192,  166,  280,  290,  192,  165,  192,  192,
      197,  240,  240,  240,  197,  167,  197,  197,  343,  286,
      192,  342,   82,  275,  341,  340,  192,  339,  197,  192,
      290,  192,  338,  276,  197,  337,  336,  197,   82,  197,
      174,   82,  335,   82,  165,  165,  165,  165,  334,  243,
      243,  243,  245,  245,  350,  350,  246,  246,  246,  174,
      333,  287,  287,  287,  286,  286,  332,  331,   82,   82,
       82,  330,  165,  329,  287,  287,  287,  328,  327,  326,

      245,  325,  324,  323,  246,  247,  247,  247,  247,  287,
      322,  321,  286,  320,  171,  319,  247,  248,  247,  247,
      318,  109,  287,  109,  109,  317,  111,  112,  316,  315,
      314,  313,  312,  247,  247,  248,  247,  247,  247,  247,
      311,  109,  310,  192,  109,  309,  109,  192,  308,  192,
      192,  111,  112,  307,  306,  305,  304,  303,  302,  301,
      300,  192,  299,  298,  297,  296,  295,  192,  294,  293,
      192,  292,  192,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   70,   70,   70,   70,   70,   70,   70,   70,   70,

       76,  291,   76,  285,  284,   76,   76,   77,  283,   77,
       77,   77,  122,  282,  281,  122,  122,  169,  278,  277,
      169,  169,  170,  170,  274,  170,  170,  172,  172,  172,
      172,  172,  172,  172,  172,  172,  175,  175,  273,  272,
      175,  175,  188,  271,  188,  188,  188,  188,  188,  188,
      188,  288,  270,  269,  268,  288,  289,  267,  266,  289,
      289,  265,  264,  263,  262,  261,  260,  259,  258,  257,
      256,  255,  254,  253,  252,  251,  250,  249,  244,  350,
      173,  242,  171,  236,  235,  231,  230,  229,  228,  227,
      224,  223,  222,  221,  220,  219,  218,  217,  216,  215,

      214,  213,  212,  211,  210,  207,  206,  205,  200,  195,
      194,  185,  184,  183,  182,  181,  180,  179,  178,  177,
      174,  174,  173,  171,  164,  163,  160,  147,  146,  127,
      126,  121,  120,  119,  114,   79,   78,   69,   68,  350,
        7,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,

      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350
    } ;

static const flex_int16_t yy_chk[718] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    4,    5,    6,
       14,    5,    6,   15,   22,   18,   32,   32,    3,    4,
       33,   33,   52,  363,   23,   44,   52,   22,   15,   15,

       15,   15,   18,   23,   25,   42,   23,   42,   44,   42,
       43,   45,   54,   45,   25,   25,  151,   43,   54,   14,
       19,   19,  151,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   26,   46,   27,   59,

       26,  362,   46,   27,   53,   26,   26,   51,   26,   26,
       26,   27,   29,   53,   51,   47,   48,   26,   26,   26,
       29,   47,   47,   29,   48,   56,   47,   70,  348,   48,
       29,   27,   28,   28,   28,   28,   55,  127,   56,  160,
       55,  127,   29,  160,   28,   59,  102,  102,   28,  342,
       28,   28,   28,   28,   28,   28,  109,  110,  110,  110,
       28,  341,   28,  108,  108,  129,   70,  123,   28,  340,
      129,   28,  130,   28,   28,  134,  134,  130,   28,   28,
       39,  109,  166,  166,   39,  108,   39,   39,  157,   39,
       39,  157,  123,   74,   74,   74,   74,  157,   39,   75,

       75,   75,   75,  339,   39,   74,  338,   39,   84,   39,
      108,  239,  239,   74,   39,   39,   74,   84,   84,   84,
      232,   74,  112,   74,  232,  248,  112,   75,  112,  112,
      125,  167,  167,  167,  125,   74,  125,  125,  330,  239,
      112,  326,   84,  228,  324,  323,  112,  321,  125,  112,
      248,  112,  320,  228,  125,  313,  312,  125,   84,  125,
      176,   84,  311,   84,  165,  165,  165,  165,  310,  176,
      176,  176,  189,  189,  189,  189,  191,  191,  191,  243,
      309,  240,  240,  240,  286,  286,  306,  305,  243,  243,
      243,  304,  165,  303,  287,  287,  287,  302,  301,  300,

      189,  299,  298,  297,  191,  193,  193,  193,  193,  240,
      294,  292,  286,  291,  289,  285,  193,  193,  193,  193,
      284,  193,  287,  193,  193,  282,  193,  193,  281,  279,
      278,  277,  276,  193,  193,  193,  193,  193,  193,  193,
      275,  193,  274,  290,  193,  273,  193,  290,  272,  290,
      290,  193,  193,  271,  270,  269,  268,  267,  265,  264,
      262,  290,  261,  258,  257,  256,  255,  290,  254,  253,
      290,  251,  290,  351,  351,  351,  351,  351,  351,  351,
      351,  351,  352,  352,  352,  352,  352,  352,  352,  352,
      352,  353,  353,  353,  353,  353,  353,  353,  353,  353,

      354,  250,  354,  238,  237,  354,  354,  355,  236,  355,
      355,  355,  356,  234,  233,  356,  356,  357,  231,  230,
      357,  357,  358,  358,  227,  358,  358,  359,  359,  359,
      359,  359,  359,  359,  359,  359,  360,  360,  226,  225,
      360,  360,  361,  224,  361,  361,  361,  361,  361,  361,
      361,  364,  223,  222,  221,  364,  365,  220,  219,  365,
      365,  218,  217,  215,  214,  212,  211,  210,  209,  208,
      207,  206,  204,  202,  201,  199,  198,  195,  187,  175,
      172,  171,  170,  159,  158,  156,  155,  154,  153,  152,
      150,  149,  148,  147,  146,  145,  144,  143,  142,  141,

      140,  138,  137,  136,  135,  133,  132,  131,  128,  115,
      114,  101,  100,   99,   98,   97,   96,   95,   93,   85,
       83,   82,   78,   77,   67,   64,   57,   50,   49,   41,
       40,   36,   35,   34,   30,   17,   16,   13,   12,    7,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,

      350,  350,  350,  350,  350,  350,  350,  350,  350,  350,
      350,  350,  350,  350,  350,  350,  350
    } ;

static const flex_int16_t yy_rule_linenum[142] =
    {   0,
      267,  268,  269,  271,  272,  273,  274,  276,  277,  278,
      279,  281,  283,  293,  306,  307,  308,  309,  310,  311,
      312,  313,  314,  315,  316,  317,  318,  319,  320,  321,
      322,  323,  324,  325,  326,  327,  328,  329,  330,  331,
      332,  333,  334,  335,  336,  337,  338,  339,  340,  341,
      342,  343,  344,  345,  346,  347,  348,  349,  352,  353,
      354,  356,  357,  359,  360,  361,  362,  363,  364,  365,
      366,  367,  368,  369,  370,  371,  372,  373,  374,  375,
      376,  377,  378,  379,  380,  381,  382,  383,  385,  396,
      397,  398,  399,  400,  401,  402,  403,  404,  405,  406,

      407,  408,  409,  410,  411,  412,  413,  414,  415,  416,
      417,  418,  419,  420,  421,  422,  423,  425,  426,  427,
      428,  429,  430,  431,  432,  433,  434,  435,  436,  437,
      438,  439,  441,  559,  564,  579,  600,  613,  658,  706,
      720
    } ;

#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "pkl-lex.l"
/* pkl-lex.l - Lexer for Poke.  */
/* Copyright (C) 2019, 2020, 2021, 2022, 2023, 2024, 2025, 2026 Jose E.
 * Marchesi */
/* This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/* Automake needs this.  */
#define YY_NO_INPUT 1
#line 33 "pkl-lex.l"
   /* %option yylineno */

#include <string.h>
#include <unistd.h>
#include <ctype.h>
#include <assert.h>
#include <stdlib.h>
#include <setjmp.h>

#include "pk-utils.h"
#include "pkl.h"
#include "pkl-ast.h"
#include "pkl-env.h"
#include "pkl-diag.h"
#include "pkl-parser.h"
#define YYSTYPE PKL_TAB_STYPE
#define YYLTYPE pkl_ast_loc
#define YYDEBUG 1
#include <pkl-tab.h>

#define RESTORE_LOC                             \
  do                                            \
    {                                           \
      yylloc = &yyextra->prev_loc;              \
    }                                           \
  while (0)

#define YY_FATAL_ERROR(msg)                             \
  do                                                    \
    {                                                   \
     YYLTYPE *loc = yyget_lloc (yyscanner);             \
     YY_EXTRA_TYPE extra = yyget_extra (yyscanner);     \
     pkl_error (extra->compiler, extra->ast, *loc, "%s",  \
                msg);                                     \
     longjmp (extra->toplevel, 1);                      \
     /* kludge to avoid compiler warning */             \
     void *x = yy_fatal_error; x = x;                   \
    }                                                   \
  while (0)

#define YY_USER_ACTION                                  \
  do                                                    \
    {                                                   \
     int i;                                             \
                                                        \
     /* Save a copy of the current location */          \
     /* so we can restore it when we call   */          \
     /* REJECT. */                                      \
     yyextra->prev_loc = *yylloc;                       \
                                                        \
     yylloc->first_line = yylloc->last_line;            \
     yylloc->first_column = yylloc->last_column;        \
                                                        \
     for (i = 0; yytext[i] != '\0'; i++)                \
       {                                                \
         if (yytext[i] == '\n')                         \
           {                                            \
             yylloc->last_line++;                       \
             yylloc->last_column = 1;                   \
           }                                            \
         else                                           \
           yylloc->last_column++;                       \
       }                                                \
                                                        \
     yyextra->nchars += yyleng;                         \
    } while (0);

/* Note that the following function assumes that STR is a pointer of a
   string that satisfies the regexp
   ({HEXCST}|{BINCST}|{OCTCST}|{DECCST}) */

int
pkl_lex_get_base (const char *str, int *offset)
{
 int base = 10;
 *offset = 0;

 if (str[0] == '0')
  {
    if (str[1] == 'x' || str[1] == 'X')
    {
      base = 16;
      *offset = 2;
    }
    else if ((str[1] == 'b' || str[1] == 'B')
             && (str[2] != '\0'))
    {
      /* Note the above check for \0 is to distinguish these two
         cases: 0[bB][0-1]+ and 0[bB]  */
      base = 2;
      *offset = 2;
    }
    else if (str[1] == 'o' || str[1] == 'O')
    {
      base = 8;
      *offset = 2;
    }
  }
  return base;
}

/* Parse the suffix for integer literals.

   If there's no [uU] chars, set *SIGNED_P to 0, otherwise 1.
   If there's no [tTnNbBhHlL] chars, set *WIDTH to 0, otherwise set
   *WIDTH to corresponding width.  */

void
parse_integer_literal_suffix (int *signed_p, int *width, const char *end)
{
  *signed_p = 1;
  if (*end == 'u' || *end == 'U'
      || (*end != '\0' && (*(end + 1) == 'u' || *(end + 1) == 'U')))
    *signed_p = 0;
  else if (*end == 't' || *end == 'T'
      || ((*end != '\0') && (*(end + 1) == 't' || *(end + 1) == 'T')))
    *signed_p = 0;

  *width = 0;
  if (*end == 'l' || *end == 'L'
      || ((*end != '\0') && (*(end + 1) == 'l' || *(end + 1) == 'L')))
    *width = 64;
  else  if (*end == 'h' || *end == 'H'
      || ((*end != '\0') && (*(end + 1) == 'h' || *(end + 1) == 'H')))
    *width = 16;
  else  if (*end == 'b' || *end == 'B'
      || ((*end != '\0') && (*(end + 1) == 'b' || *(end + 1) == 'B')))
    *width = 8;
  else if (*end == 'n' || *end == 'N'
      || ((*end != '\0') && (*(end + 1) == 'n' || *(end + 1) == 'N')))
    *width = 4;
  else if (*end == 't' || *end == 'T'
      || ((*end != '\0') && (*(end + 1) == 't' || *(end + 1) == 'T')))
    *width = 1;
}

/* If the width is not already known (e.g., based on the suffix),
   the type of the integer constant is the smallest signed or unsigned
   integer capable of holding it, starting with 32 bits, in steps of
   power of two and up to 64 bits.  But note these are positive values!  */

static int
integer_literal_width (uint64_t value, int signed_p)
{
  if (value > 0x0000000080000000 && value <= 0x00000000ffffffff)
    return signed_p ? 64 : 32;
  else if (value & 0xffffffff00000000)
    return 64;
  return 32;
}

/* Handle overflow for integer literals:
     - Signed integer: check for overflow (of course only for positives).
     - Unsigned integers: truncate the VALUE to fit into the WIDTH.
   If the bit kidth of VALUE is not known, choose a proper width.

   Return 1 on detection of overflow, otherwise 0.  */

static int
integer_literal_overflow_handling (uint64_t *value, int signed_p, int width)
{
  /* Handle overflow in signed integers.  Note that the lexer only
     sees positive signed integers.  */
  if (signed_p && *value >= ((uint64_t)1 << (width - 1)))
    return 1;

  /* Handle truncation in unsigned integers.  */
  if (!signed_p && width < 64)
   *value &= ((uint64_t) 1 << width) - 1;

  return 0;
}

static char *
build_overflow_error_msg (uint64_t value, int width)
{
  char *msg = NULL;
  const char *suffix = (width == 64 ? "L"
                        : width == 8 ? "B"
                        : width == 16 ? "H"
                        : width == 4 ? "N"
                        : "");

  asprintf (&msg,
            "signed overflow\ntry: %" PRIu64 "U%s as int<%d>",
            value, suffix, width);
  return msg;
}

#line 1304 "pkl-lex.c"

#line 1306 "pkl-lex.c"

#define INITIAL 0
#define C_COMMENT 1
#define SHEBANG_COMMENT 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#define YY_EXTRA_TYPE struct pkl_parser *

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

/* %if-c-only */

static int yy_init_globals ( yyscan_t yyscanner );

/* %endif */

/* %if-reentrant */

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* %endif */

/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* %if-bison-bridge */

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
/* %% [7.0] user's declarations go here */
#line 253 "pkl-lex.l"



#line 257 "pkl-lex.l"
  /* Handle the support for multiple parsers.  */

  if (yyextra->start_token)
  {
    int t = yyextra->start_token;
    yyextra->start_token = 0;
    return t;
  }


#line 1688 "pkl-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 351 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 641 );

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
					{
					yyg->yy_full_match = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 142 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 142 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 143 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 267 "pkl-lex.l"
{ /* Ignore newlines.  */  }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 268 "pkl-lex.l"
{ /* Ignore whitespace.  */ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 269 "pkl-lex.l"
{ /* Ignore form feed ^L characters.  */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 271 "pkl-lex.l"
{ BEGIN(C_COMMENT); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 272 "pkl-lex.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 273 "pkl-lex.l"
{  }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 274 "pkl-lex.l"
{  }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 276 "pkl-lex.l"
{ BEGIN(SHEBANG_COMMENT); }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 277 "pkl-lex.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 278 "pkl-lex.l"
{  }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 279 "pkl-lex.l"
{  }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 281 "pkl-lex.l"
{ /* Partial-line comment.  */ }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 283 "pkl-lex.l"
{
  pkl_ast_node type
    = pkl_ast_make_integral_type (yyextra->ast, 64, 0);
  yylval->ast = pkl_ast_make_integer (yyextra->ast,
                                      yylloc->first_line);
  PKL_AST_TYPE (yylval->ast) = ASTREF (type);

  return INTEGER;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 293 "pkl-lex.l"
{
  pkl_ast_node type
    = pkl_ast_make_string_type (yyextra->ast);

  yylval->ast = pkl_ast_make_string (yyextra->ast,
                                     yyextra->filename
                                     ? yyextra->filename
                                     : "<stdin>");
  PKL_AST_TYPE (yylval->ast) = ASTREF (type);
  return STR;
 }
	YY_BREAK
/* BEGINNING OF KEYWORDS */
case 15:
YY_RULE_SETUP
#line 306 "pkl-lex.l"
{ return ASM; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 307 "pkl-lex.l"
{ return PINNED; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 308 "pkl-lex.l"
{ return STRUCT; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 309 "pkl-lex.l"
{ return UNION; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 310 "pkl-lex.l"
{ return ELSE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 311 "pkl-lex.l"
{ return WHILE; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 312 "pkl-lex.l"
{ return UNTIL; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 313 "pkl-lex.l"
{ return FOR; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 314 "pkl-lex.l"
{ return IN; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 315 "pkl-lex.l"
{ return WHERE; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 316 "pkl-lex.l"
{ return IF; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 317 "pkl-lex.l"
{ return SIZEOF; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 318 "pkl-lex.l"
{ return TYPEOF; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 319 "pkl-lex.l"
{ return APUSH; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 320 "pkl-lex.l"
{ return APOP; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 321 "pkl-lex.l"
{ return DEFUN; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 322 "pkl-lex.l"
{ return METHOD; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 323 "pkl-lex.l"
{ return DEFTYPE; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 324 "pkl-lex.l"
{ return DEFVAR; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 325 "pkl-lex.l"
{ return DEFUNIT; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 326 "pkl-lex.l"
{ return BREAK; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 327 "pkl-lex.l"
{ return CONTINUE; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 328 "pkl-lex.l"
{ return RETURN; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 329 "pkl-lex.l"
{ return STRING; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 330 "pkl-lex.l"
{ return AS; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 331 "pkl-lex.l"
{ return TRY; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 332 "pkl-lex.l"
{ return CATCH; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 333 "pkl-lex.l"
{ return RAISE; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 334 "pkl-lex.l"
{ return VOID; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 335 "pkl-lex.l"
{ return ANY; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 336 "pkl-lex.l"
{ return PRINT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 337 "pkl-lex.l"
{ return PRINTF; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 338 "pkl-lex.l"
{ return ISA; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 339 "pkl-lex.l"
{ return UNMAP; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 340 "pkl-lex.l"
{ return REMAP; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 341 "pkl-lex.l"
{ return BIG; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 342 "pkl-lex.l"
{ return LITTLE; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 343 "pkl-lex.l"
{ return LOAD; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 344 "pkl-lex.l"
{ return LAMBDA; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 345 "pkl-lex.l"
{ return ASSERT; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 346 "pkl-lex.l"
{ return FORMAT; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 347 "pkl-lex.l"
{ return ENUM; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 348 "pkl-lex.l"
{ return COMPUTED; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 349 "pkl-lex.l"
{ return IMMUTABLE; }
	YY_BREAK
/* END OF KEYWORDS */
case 59:
YY_RULE_SETUP
#line 352 "pkl-lex.l"
{ return UINTCONSTR; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 353 "pkl-lex.l"
{ return INTCONSTR; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 354 "pkl-lex.l"
{ return OFFSETCONSTR; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 356 "pkl-lex.l"
{ return THREEDOTS; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 357 "pkl-lex.l"
{ return RANGEA; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 359 "pkl-lex.l"
{ return POWA; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 360 "pkl-lex.l"
{ return MULA; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 361 "pkl-lex.l"
{ return DIVA; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 362 "pkl-lex.l"
{ return MODA; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 363 "pkl-lex.l"
{ return ADDA; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 364 "pkl-lex.l"
{ return SUBA; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 365 "pkl-lex.l"
{ return SLA; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 366 "pkl-lex.l"
{ return SRA; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 367 "pkl-lex.l"
{ return BANDA; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 368 "pkl-lex.l"
{ return IORA; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 369 "pkl-lex.l"
{ return XORA; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 370 "pkl-lex.l"
{ return BCONC; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 371 "pkl-lex.l"
{ return EXCOND; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 372 "pkl-lex.l"
{ return OR; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 373 "pkl-lex.l"
{ return AND; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 374 "pkl-lex.l"
{ return IMPL; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 375 "pkl-lex.l"
{ return EQ; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 376 "pkl-lex.l"
{ return NE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 377 "pkl-lex.l"
{ return LE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 378 "pkl-lex.l"
{ return GE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 379 "pkl-lex.l"
{ return SL; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 380 "pkl-lex.l"
{ return SR; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 381 "pkl-lex.l"
{ return INC; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 382 "pkl-lex.l"
{ return DEC; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 383 "pkl-lex.l"
{ return IND; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 385 "pkl-lex.l"
{
  int signed_p, width;

  parse_integer_literal_suffix (&signed_p, &width, &yytext[1]);
  if (!width)
    width = 32;
  yylval->ast = pkl_ast_make_integral_type (yyextra->ast, width, signed_p);
  yylval->ast = ASTREF (yylval->ast);
  return ARRSUF;
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 396 "pkl-lex.l"
{ return '['; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 397 "pkl-lex.l"
{ return ']'; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 398 "pkl-lex.l"
{ return '('; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 399 "pkl-lex.l"
{ return ')'; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 400 "pkl-lex.l"
{ return '{'; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 401 "pkl-lex.l"
{ return '}'; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 402 "pkl-lex.l"
{ return ','; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 403 "pkl-lex.l"
{ return '='; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 404 "pkl-lex.l"
{ return '?'; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 405 "pkl-lex.l"
{ return ';'; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 406 "pkl-lex.l"
{ return ':'; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 407 "pkl-lex.l"
{ return '|'; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 408 "pkl-lex.l"
{ return '^'; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 409 "pkl-lex.l"
{ return '&'; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 410 "pkl-lex.l"
{ return '<'; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 411 "pkl-lex.l"
{ return '>'; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 412 "pkl-lex.l"
{ return '+'; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 413 "pkl-lex.l"
{ return '-'; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 414 "pkl-lex.l"
{ return POW; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 415 "pkl-lex.l"
{ return '*'; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 416 "pkl-lex.l"
{ return CEILDIV; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 417 "pkl-lex.l"
{ return '/'; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 418 "pkl-lex.l"
{ return '%'; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 419 "pkl-lex.l"
{ return '!'; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 420 "pkl-lex.l"
{ return '~'; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 421 "pkl-lex.l"
{ return '.'; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 422 "pkl-lex.l"
{ return NSMAP; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 423 "pkl-lex.l"
{ return '@'; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 425 "pkl-lex.l"
{ return EQF; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 426 "pkl-lex.l"
{ return NEF; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 427 "pkl-lex.l"
{ return LTF; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 428 "pkl-lex.l"
{ return GTF; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 429 "pkl-lex.l"
{ return LEF; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 430 "pkl-lex.l"
{ return GEF; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 431 "pkl-lex.l"
{ return ADDF; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 432 "pkl-lex.l"
{ return SUBF; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 433 "pkl-lex.l"
{ return POWF; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 434 "pkl-lex.l"
{ return MULF; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 435 "pkl-lex.l"
{ return CEILDIVF; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 436 "pkl-lex.l"
{ return DIVF; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 437 "pkl-lex.l"
{ return MODF; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 438 "pkl-lex.l"
{ return INCF; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 439 "pkl-lex.l"
{ return DECF; }
	YY_BREAK
case 133:
/* rule 133 can match eol */
YY_RULE_SETUP
#line 441 "pkl-lex.l"
{
  char *errmsg;
  pkl_alien_token_handler_fn cb = NULL;
  pkl_alien_dtoken_handler_fn dcb = NULL;

  if (yytext[1] == '<')
    dcb = pkl_alien_dtoken_fn (yyextra->compiler);
  else
    cb = pkl_alien_token_fn (yyextra->compiler);

  if (pkl_lexical_cuckolding_p (yyextra->compiler)
      && (cb != NULL || dcb != NULL))
    {
      struct pkl_alien_token *token
        = (cb != NULL
           ? (*cb) (yyextra->compiler, yytext + 1, &errmsg)
           : (*dcb) (yyextra->compiler, yytext[1], yytext + 1, &errmsg));

      if (token == NULL)
        {
          /* Error from alien handler.  */
          yyextra->alien_errmsg = errmsg;
          return ALIEN;
          break;
        }

      switch (token->kind)
        {
        case PKL_ALIEN_TOKEN_IDENTIFIER:
          {
            char *id = token->value.identifier;
            yylval->ast = pkl_ast_make_identifier (yyextra->ast,
                                                   id);
            free (id);
            return IDENTIFIER;
            break;
          }
        case PKL_ALIEN_TOKEN_STRING:
          {
            pkl_ast_node type = pkl_ast_make_string_type (yyextra->ast);

            yylval->ast
              = pkl_ast_make_string (yyextra->ast, token->value.string.str);
            PKL_AST_TYPE (yylval->ast) = ASTREF (type);

            return STR;
            break;
          }
        case PKL_ALIEN_TOKEN_INTEGER:
          {
            uint64_t value = token->value.integer.magnitude;
            int signed_p = token->value.integer.signed_p;
            int width = token->value.integer.width;
            pkl_ast_node type;

            if (width == 0)
              width = integer_literal_width (value, signed_p);
            if (integer_literal_overflow_handling (&value, signed_p, width))
              {
                yylval->exception_msg = build_overflow_error_msg (value, width);
                return LEXER_EXCEPTION;
              }

            type = pkl_ast_make_integral_type (yyextra->ast, width, signed_p);

            yylval->ast = pkl_ast_make_integer (yyextra->ast, value);
            PKL_AST_TYPE (yylval->ast) = ASTREF (type);

            return INTEGER;
            break;
          }
        case PKL_ALIEN_TOKEN_OFFSET:
          {
            uint64_t value = token->value.offset.magnitude;
            int signed_p = token->value.offset.signed_p;
            int width = token->value.offset.width;
            pkl_ast_node unit, magnitude, magnitude_type, offset_type, unit_type;

            if (width == 0)
              width = integer_literal_width (value, signed_p);
            if (integer_literal_overflow_handling (&value, signed_p, width))
              {
                yylval->exception_msg = build_overflow_error_msg (value, width);
                return LEXER_EXCEPTION;
              }

            /* Build the offset magnitude.  */
            magnitude_type = pkl_ast_make_integral_type (yyextra->ast, width, signed_p);
            magnitude = pkl_ast_make_integer (yyextra->ast, value);
            PKL_AST_TYPE (magnitude) = ASTREF (magnitude_type);

            /* Build the offset unit.  */
            unit_type = pkl_ast_make_integral_type (yyextra->ast, 64, 0);
            unit = pkl_ast_make_integer (yyextra->ast, token->value.offset.unit);
            PKL_AST_TYPE (unit) = ASTREF (unit_type);

            /* Build the offset value itself.  */
            offset_type = pkl_ast_make_offset_type (yyextra->ast,
                                                    magnitude_type,
                                                    unit, NULL /* ref_type */);
            yylval->ast = pkl_ast_make_offset (yyextra->ast,
                                               magnitude, unit);
            PKL_AST_TYPE (yylval->ast) = ASTREF (offset_type);
            return OFFSET;
            break;
          }
        default:
          PK_UNREACHABLE ();
          break;
        }
    }

  /* Lexical cuckolding is not enabled.  */
  yylloc->last_column -= strlen (yytext);
  RESTORE_LOC;
  REJECT;
}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 559 "pkl-lex.l"
{
  yylval->ast = pkl_ast_make_identifier (yyextra->ast, yytext + 1);
  return ATTR;
}
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 564 "pkl-lex.l"
{
  char *end;
  int base, offset;
  uint64_t value;
  pkl_ast_node type
     = pkl_ast_make_integral_type (yyextra->ast, 64, 0);

  base = pkl_lex_get_base (yytext + 1, &offset);
  value = strtoll (yytext + 1 + offset, &end, base);
  yylval->ast = pkl_ast_make_integer (yyextra->ast, value);
  PKL_AST_TYPE (yylval->ast) = ASTREF (type);

  return UNIT;
}
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 579 "pkl-lex.l"
{
   pkl_ast_node decl
      = pkl_env_lookup (yyextra->env, PKL_ENV_NS_UNITS,
                        yytext + 1, NULL, NULL);

   if (decl)
     yylval->ast = PKL_AST_DECL_INITIAL (decl);
   else
     {
       decl = pkl_env_lookup (yyextra->env, PKL_ENV_NS_MAIN,
                              yytext + 1, NULL, NULL);

       if (decl && PKL_AST_DECL_KIND (decl) == PKL_AST_DECL_KIND_TYPE)
         yylval->ast = PKL_AST_DECL_INITIAL (decl);
       else
         yylval->ast = NULL;
     }

   return UNIT;
}
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 600 "pkl-lex.l"
{
   pkl_ast_node decl
     = pkl_env_lookup (yyextra->env, PKL_ENV_NS_MAIN,
                       yytext, NULL, NULL);

   yylval->ast = pkl_ast_make_identifier (yyextra->ast, yytext);

   if (decl && PKL_AST_DECL_KIND (decl) == PKL_AST_DECL_KIND_TYPE)
     return TYPENAME;
   else
     return IDENTIFIER;
}
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 613 "pkl-lex.l"
{
  uint64_t value;
  int base, offset, signed_p, width;
  char *p, *end;
  pkl_ast_node type;

  /* First of all, strip any '_' character from yytext.  */
  for (p = yytext; *p != '\0'; p++)
  {
    char *tmp;

    while (*p == '_')
     for (tmp = p; *tmp != '\0'; tmp++)
       *tmp = *(tmp + 1);
  }

  base = pkl_lex_get_base (yytext, &offset);

  /* strtoull can fail here only in case of overflow.  */
  errno = 0;
  value = strtoull (yytext + offset, &end, base);
  if (value == ULLONG_MAX && errno == ERANGE)
    {
      yylval->exception_msg = strdup ("integer literal is too big");
      return LEXER_EXCEPTION;
    }

  parse_integer_literal_suffix (&signed_p, &width, end);

  if (width == 0)
    width = integer_literal_width (value, signed_p);
  if (integer_literal_overflow_handling (&value, signed_p, width))
    {
      yylval->exception_msg = build_overflow_error_msg (value, width);
      return LEXER_EXCEPTION;
    }

  type = pkl_ast_make_integral_type (yyextra->ast, width, signed_p);

  yylval->ast = pkl_ast_make_integer (yyextra->ast, value);
  PKL_AST_TYPE (yylval->ast) = ASTREF (type);

  return INTEGER;
}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 658 "pkl-lex.l"
{
   uint8_t value;
   pkl_ast_node type;

   if (yytext[1] == '\\')
    {
      if (yytext[2] >= '0' && yytext[2] <= '9')
        {
          char *end;
          uint64_t val64;

          /* strtoll can't fail in this context.  */
          val64 = strtoll (yytext + 2, &end, 8);
          value = (uint8_t) val64;
        }
      else
        switch (yytext[2])
          {
          case 'n':
            value = '\n';
            break;
          case 't':
            value = '\t';
            break;
          case 'r':
            value = '\r';
            break;
          case '\\':
            value = '\\';
            break;
          default:
            /* To avoid compiler warnings.  */
            value = 0;
            break;
          }
    }
   else
     value = yytext[1];

   type = pkl_ast_make_integral_type (yyextra->ast, 8, 0);
   PKL_AST_TYPE_COMPLETE (type) = PKL_AST_TYPE_COMPLETE_YES;

   yylval->ast = pkl_ast_make_integer (yyextra->ast, value);
   PKL_AST_TYPE (yylval->ast) = ASTREF (type);

   return CHAR;
}
	YY_BREAK
case 140:
/* rule 140 can match eol */
YY_RULE_SETUP
#line 706 "pkl-lex.l"
{
   pkl_ast_node type;

   /* Strip the quoting characters */
   yytext[strlen (yytext) - 1] = 0;

   type = pkl_ast_make_string_type (yyextra->ast);

   yylval->ast = pkl_ast_make_string (yyextra->ast, yytext + 1);
   PKL_AST_TYPE (yylval->ast) = ASTREF (type);

   return STR;
}
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 720 "pkl-lex.l"
{ return ERR; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 722 "pkl-lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2780 "pkl-lex.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(C_COMMENT):
			case YY_STATE_EOF(SHEBANG_COMMENT):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 351 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
/* %% [17.0] code to find the next state, and perhaps do backing up, goes here */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 351 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 350);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

/* %% [19.0] update BOL and yylineno */

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
/* %if-c-only */
void yypop_buffer_state (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (yyscan_t yyscanner)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/* %endif */

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/* %if-reentrant */

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* Accessor methods for yylval and yylloc */

/* %if-bison-bridge */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* %endif */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

/* %if-reentrant */
    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 722 "pkl-lex.l"


/*
Local variables:
mode:c
End:
*/

